Feast Python API Documentation
=============================

Client
==================

.. automodule:: feast.client
    :members:

Data Source
==================

.. automodule:: feast.data_source
    :members:


Entity
==================

.. automodule:: feast.entity
    :inherited-members:
    :members:


Feature Table
==================

.. automodule:: feast.feature_table
    :members:

Feature
==================

.. automodule:: feast.feature
    :inherited-members:
    :members:

Constants
==================

.. automodule:: feast.constants
    :members:
    :exclude-members: AuthProvider, ConfigMeta
